==> moodle_1.3.1.orig.tar.gz: moodle/lang/pl/lesson.php <==
<?PHP // $Id: lesson.php,v 1.4 2004/04/09 19:18:34 adamtpaw Exp $ 
      // lesson.php - created with Moodle 1.2.1 beta (2004032200)


$string['actionaftercorrectanswer'] = 'Reakcja po poprawnej odpowiedzi';
$string['addanewpage'] = 'Dodaj now stron';
$string['addpagehere'] = 'Wstaw tutaj now stron';
$string['answer'] = 'Odpowied';
$string['answersfornumerical'] = 'Odpowiedzi dla numerycznych pyta powinny odpowiada wartociom Minimum i Maximum';
$string['attempt'] = 'Prba: $a';
$string['attempts'] = 'Prby';
$string['available'] = 'Dostpne od';
$string['canretake'] = 'Powtrzenie lekcji';
$string['casesensitive'] = 'Zalene od wielkoci liter';
$string['checknavigation'] = 'Sprawd nawigacj';
$string['checkquestion'] = 'Sprawd pytanie';
$string['confirmdeletionofthispage'] = 'Potwierd usunicie tej strony';
$string['congratulations'] = 'Gratualcje - koniec lekcji';
$string['continue'] = 'Kontynuuj';
$string['deadline'] = 'Termin kocowy';
$string['deletingpage'] = 'Usuwanie strony: $a';
$string['displayofgrade'] = 'Wywietl ocen studentowi';
$string['endoflesson'] = 'Koniec lekcji';
$string['fileformat'] = 'Format pliku';
$string['firstanswershould'] = 'Pierwsza odpowied powinna przenie do &quot;odpowiedniej&quot strony';
$string['gradeis'] = 'Ocena: $a';
$string['importquestions'] = 'Zaimportuj pytania';
$string['jumpto'] = 'Przejd do';
$string['maximumnumberofanswers'] = 'Maksymalna liczba odpowiedzi';
$string['maximumnumberofattempts'] = 'Maksymalna liczba prb';
$string['modulename'] = 'Lekcja';
$string['modulenameplural'] = 'Lekcje';
$string['movepagehere'] = 'Przesu stron tutaj';
$string['moving'] = 'Przesuwanie strony: $a';
$string['movingtonextpage'] = 'Do nastpnej strony';
$string['multianswer'] = 'Wiele odpowiedzi';
$string['multipleanswer'] = 'Wielokrotne odpowiedzi';
$string['nextpage'] = 'Nastpna strona';
$string['noanswer'] = 'Brak odpowiedzi';
$string['noattemptrecordsfound'] = 'Brak prb: nie przyznano oceny';
$string['normal'] = 'Normalnie - id zgodnie z trybem lekcji';
$string['numberofcorrectanswers'] = 'Ilo poprawnych odpowiedzi: $a';
$string['numberofcorrectmatches'] = 'Ilo poprawnych pocze: $a';
$string['numberofpagestoshow'] = 'Ilo stron (kart) do wywietlenia';
$string['numberofpagesviewed'] = 'Ilo obejrzanych strony: $a';
$string['ordered'] = 'Poukadane';
$string['outof'] = 'Z $a';
$string['page'] = 'Strona: $a';
$string['pagecontents'] = 'Spis treci';
$string['pagetitle'] = 'Tytu strony';
$string['pleasecheckoneanswer'] = 'Prosz sprawd jedn odpowied';
$string['pleasecheckoneormoreanswers'] = 'Sprawd jedn lub wicej odpowiedzi';
$string['pleaseenteryouranswerinthebox'] = 'Prosz wpisz swoj odpowied';
$string['pleasematchtheabovepairs'] = 'Pocz powysze pary';
$string['questionoption'] = 'Opcja pytania';
$string['questiontype'] = 'Typ pytania';
$string['response'] = 'Informacja zwrotna';
$string['sanitycheckfailed'] = 'Ta prba zostaa usunita!';
$string['savepage'] = 'Zapisz stron';
$string['showanunansweredpage'] = 'Umoliw wielokrotne przegldanie stron z bdn odpowiedzi';
$string['showanunseenpage'] = 'Nigdy nie pokazuj tej samej strony dwukrotnie';
$string['singleanswer'] = 'Pojedyncza odpowied';
$string['thatsthecorrectanswer'] = 'To jest poprawna odpowied';
$string['thatsthewronganswer'] = 'To jest bdna odpowied';
$string['thispage'] = 'Ta strona';
$string['youhaveseen'] = 'Widziae ju wicej ni jedn stron tej lekcji. <br/> Czy chciaby zacz od ostatniej strony, ktr przegldae?';
$string['youranswer'] = 'Twoja odpowied';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.4 (2004083100)


$string['actionaftercorrectanswer'] = 'Reakcja po poprawnej odpowiedzi';
$string['addabranchtable'] = 'Wstaw Tabel Wtkw';
$string['addanendofbranch'] = 'Wstaw Koniec Tabeli Wtkw';
$string['addaquestionpage'] = 'Wstaw Stron Pyta';
$string['answer'] = 'Odpowied';
$string['answersfornumerical'] = 'Odpowiedzi dla numerycznych pyta powinny odpowiada wartociom Minimum i Maximum';
$string['attempt'] = 'Prba: $a';
$string['attempts'] = 'Prby';
$string['available'] = 'Dostpne od';
$string['branchtable'] = 'Tabela Wtkw';
$string['canretake'] = 'Powtrzenie lekcji';
$string['casesensitive'] = 'Zalene od wielkoci liter';
$string['checkbranchtable'] = 'Sprawd Tabel Wtkw';
$string['checknavigation'] = 'Sprawd nawigacj';
$string['checkquestion'] = 'Sprawd pytanie';
$string['confirmdeletionofthispage'] = 'Potwierd usunicie tej strony';
$string['congratulations'] = 'Gratualcje - koniec lekcji';
$string['continue'] = 'Kontynuuj';
$string['deadline'] = 'Termin kocowy';
$string['deleting'] = 'Usuwanie';
$string['deletingpage'] = 'Usuwanie strony: $a';
$string['description'] = 'Opis';
$string['displayofgrade'] = 'Wywietl ocen studentowi';
$string['endofbranch'] = 'Koniec wtka';
$string['endoflesson'] = 'Koniec lekcji';
$string['fileformat'] = 'Format pliku';
$string['firstanswershould'] = 'Pierwsza odpowied powinna przenie do \"odpowiedniej\" strony';
$string['gradeis'] = 'Ocena: $a';
$string['handlingofretakes'] = 'Zarzdzanie poprawkami';
$string['here'] = 'tutaj';
$string['importquestions'] = 'Zaimportuj pytania';
$string['jump'] = 'Przejd';
$string['maximumnumberofanswersbranches'] = 'Maksymalna liczba odpowiedzi/przej';
$string['maximumnumberofattempts'] = 'Maksymalna liczba prb';
$string['minimumnumberofquestions'] = 'Minimalna liczba pyta';
$string['modulename'] = 'Lekcja';
$string['modulenameplural'] = 'Lekcje';
$string['movepagehere'] = 'Przesu stron tutaj';
$string['moving'] = 'Przesuwanie strony: $a';
$string['movingtonextpage'] = 'Do nastpnej strony';
$string['multianswer'] = 'Wiele odpowiedzi';
$string['multipleanswer'] = 'Wielokrotne odpowiedzi';
$string['nextpage'] = 'Nastpna strona';
$string['noanswer'] = 'Brak odpowiedzi';
$string['noattemptrecordsfound'] = 'Brak prb: nie przyznano oceny';
$string['nobranchtablefound'] = 'Nie znaleziono Tabeli Wtkw';
$string['normal'] = 'Normalnie - id zgodnie z trybem lekcji';
$string['notdefined'] = 'Brak definicji';
$string['notitle'] = 'Brak tytuu';
$string['numberofcorrectanswers'] = 'Ilo poprawnych odpowiedzi: $a';
$string['numberofcorrectmatches'] = 'Ilo poprawnych pocze: $a';
$string['numberofpagestoshow'] = 'Ilo stron (kart) do wywietlenia';
$string['numberofpagesviewed'] = 'Ilo obejrzanych strony: $a';
$string['ordered'] = 'Poukadane';
$string['outof'] = 'Z $a';
$string['page'] = 'Strona: $a';
$string['pagecontents'] = 'Spis treci';
$string['pages'] = 'Strony';
$string['pagetitle'] = 'Tytu strony';
$string['pleasecheckoneanswer'] = 'Prosz sprawd jedn odpowied';
$string['pleasecheckoneormoreanswers'] = 'Sprawd jedn lub wicej odpowiedzi';
$string['pleaseenteryouranswerinthebox'] = 'Prosz wpisz swoj odpowied';
$string['pleasematchtheabovepairs'] = 'Pocz powysze pary';
$string['questionoption'] = 'Opcja pytania';
$string['questiontype'] = 'Typ pytania';
$string['reached'] = 'osignity';
$string['redisplaypage'] = 'Ponownie wywietl stron';
$string['response'] = 'Informacja zwrotna';
$string['sanitycheckfailed'] = 'Ta prba zostaa usunita!';
$string['savepage'] = 'Zapisz stron';
$string['showanunansweredpage'] = 'Umoliw wielokrotne przegldanie stron z bdn odpowiedzi';
$string['showanunseenpage'] = 'Nigdy nie pokazuj tej samej strony dwukrotnie';
$string['singleanswer'] = 'Pojedyncza odpowied';
$string['thatsthecorrectanswer'] = 'To jest poprawna odpowied';
$string['thatsthewronganswer'] = 'To jest bdna odpowied';
$string['thefollowingpagesjumptothispage'] = 'Nastpujce strony prowadz do tej strony';
$string['thispage'] = 'Ta strona';
$string['useeditor'] = 'Uyj edytora';
$string['usemaximum'] = 'Uyj maksimum';
$string['usemean'] = 'Uyj redniej';
$string['youhaveseen'] = 'Widziae ju wicej ni jedn stron tej lekcji. <br/> Czy chciaby zacz od ostatniej strony, ktr przegldae?';
$string['youranswer'] = 'Twoja odpowied';
$string['yourcurrentgradeis'] = 'Twoja aktualna ocena to $a';
$string['youshouldview'] = 'Powiniene zobaczy co najmniej &a';

?>
